@@ -50,6 +50,12 @@ try:
 
     # Set the dpi scaling
     _qtapp.setAttribute(_qtc.Qt.AA_EnableHighDpiScaling, True)
+    
+    # Standard Fusion light theme
+    _qtapp.setStyle('Fusion')
+    
+    # Dark theme
+    if settings['dark_theme']: from . import _fusion_theme    
 
 except:
     _warn("pyqtgraph version 0.11 or higher is required (use a conda or pip install) if you wish to use dialogs or egg.")
@@ -57,8 +63,9 @@ except:
     _qtc = None
     _qt  = None
     _qtw = None
+    _qtapp = None
+
 
-if _qtapp is not None: _qtapp.setStyle('Fusion')
 
 # some defaults
 _mpl.rcParams['figure.facecolor']='w'
